/*!
 * vue-framework7 v0.5.8
 * https://github.com/lmk123/vue-framework7
 * Released under the MIT License.
 */
(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue')) :
	typeof define === 'function' && define.amd ? define(['exports', 'vue'], factory) :
	(factory((global.f7 = {}),global.Vue));
}(this, (function (exports,Vue) { 'use strict';

Vue = Vue && Vue.hasOwnProperty('default') ? Vue['default'] : Vue;

// https://github.com/nolimits4web/Framework7/blob/v1.6.4/src/js/framework7/proto-device.js

var device = {};
var ua = navigator.userAgent;
// var $ = Dom7

var windows = ua.match(/(Windows Phone);?[\s/]+([\d.]+)?/);
var android = ua.match(/(Android);?[\s/]+([\d.]+)?/);
var ipad = ua.match(/(iPad).*OS\s([\d_]+)/);
var ipod = ua.match(/(iPod)(.*OS\s([\d_]+))?/);
var iphone = !ipad && ua.match(/(iPhone\sOS|iOS)\s([\d_]+)/);

device.ios = device.android = device.windows = device.iphone = device.ipod = device.ipad = device.androidChrome = false;

// Windows
if (windows) {
  device.os = 'windows';
  device.osVersion = windows[2];
  device.windows = true;
}
// Android
if (android && !windows) {
  device.os = 'android';
  device.osVersion = android[2];
  device.android = true;
  device.androidChrome = ua.toLowerCase().indexOf('chrome') >= 0;
}
if (ipad || iphone || ipod) {
  device.os = 'ios';
  device.ios = true;
}
// iOS
if (iphone && !ipod) {
  device.osVersion = iphone[2].replace(/_/g, '.');
  device.iphone = true;
}
if (ipad) {
  device.osVersion = ipad[2].replace(/_/g, '.');
  device.ipad = true;
}
if (ipod) {
  device.osVersion = ipod[3] ? ipod[3].replace(/_/g, '.') : null;
  device.iphone = true;
}
// iOS 8+ changed UA
if (device.ios && device.osVersion && ua.indexOf('Version/') >= 0) {
  if (device.osVersion.split('.')[0] === '10') {
    device.osVersion = ua.toLowerCase().split('version/')[1].split(' ')[0];
  }
}

// Webview
device.webView = (iphone || ipad || ipod) && ua.match(/.*AppleWebKit(?!.*Safari)/i);

// Minimal UI
if (device.os && device.os === 'ios') {
  var osVersionArr = device.osVersion.split('.');
  var metaViewport = document.querySelector('meta[name="viewport"]');
  device.minimalUi = !device.webView &&
    (ipod || iphone) &&
    (osVersionArr[0] * 1 === 7 ? osVersionArr[1] * 1 >= 1 : osVersionArr[0] * 1 > 7) &&
    // $('meta[name="viewport"]').length > 0 && $('meta[name="viewport"]').attr('content').indexOf('minimal-ui') >= 0
    metaViewport && metaViewport.getAttribute('content').indexOf('minimal-ui') >= 0;
}

// Check for status bar and fullscreen app mode
// var windowWidth = $(window).width()
// var windowHeight = $(window).height()
var windowWidth = window.innerWidth;
var windowHeight = window.innerHeight;

device.needsStatusBar = function () {
  if (device.webView && (windowWidth * windowHeight === screen.width * screen.height)) {
    return true
  }
  return false
};
device.statusBar = device.needsStatusBar();

// Classes
var classNames = [];

// Pixel Ratio
device.pixelRatio = window.devicePixelRatio || 1;
classNames.push('pixel-ratio-' + Math.floor(device.pixelRatio));
if (device.pixelRatio >= 2) {
  classNames.push('retina');
}

// OS classes
if (device.os) {
  classNames.push(device.os, device.os + '-' + device.osVersion.split('.')[0], device.os + '-' + device.osVersion.replace(/\./g, '-'));
  if (device.os === 'ios') {
    var major = parseInt(device.osVersion.split('.')[0], 10);
    for (var i = major - 1; i >= 6; i--) {
      classNames.push('ios-gt-' + i);
    }
  }
}

// Status bar classes
if (device.statusBar) {
  classNames.push('with-statusbar-overlay');
} else {
  // $('html').removeClass('with-statusbar-overlay')
  document.documentElement.classList.remove('with-statusbar-overlay');
}

// Add html classes
// if (classNames.length > 0) $('html').addClass(classNames.join(' '))
if (classNames.length > 0) { (ref = document.documentElement.classList).add.apply(ref, classNames); }

// Export object
// return device
var ref;

var transitionProp;
var transitionEndEvent;
var animationProp;
var animationEndEvent;

if ('ontransitionend' in window) {
  transitionProp = 'transition';
  transitionEndEvent = 'transitionend';
} else {
  transitionProp = 'WebkitTransition';
  transitionEndEvent = 'webkitTransitionEnd';
}

if ('onanimationend' in window) {
  animationProp = 'animation';
  animationEndEvent = 'animationend';
} else {
  animationProp = 'WebkitAnimation';
  animationEndEvent = 'webkitAnimationEnd';
}

/**
 * 只执行一次过渡结束的事件
 * @param {Element} el
 * @param {function} handler
 */
function oneTransitionEnd (el, handler) {
  el.addEventListener(transitionEndEvent, function h (e) {
    handler.call(el, e);
    el.removeEventListener(transitionEndEvent, h);
  });
}

/**
 * 只执行一次动画结束的事件
 * @param {Element} el
 * @param {function} handler
 */
function oneAnimationEnd (el, handler) {
  el.addEventListener(animationEndEvent, function h (e) {
    handler.call(el, e);
    el.removeEventListener(animationEndEvent, h);
  });
}

var IS_TOUCH = 'ontouchstart' in window;
var TOUCH_START = IS_TOUCH ? 'touchstart' : 'mousedown';
var TOUCH_MOVE = IS_TOUCH ? 'touchmove' : 'mousemove';
var TOUCH_END = IS_TOUCH ? 'touchend' : 'mouseup';

function defaultPullState () {
  return {
    up: false,
    startX: 0,
    startY: 0,
    distance: 0,
    pullStart: false
  }
}

var getPageXY = IS_TOUCH ? function (event) {
  var firstTouch = event.targetTouches[0];
  return {
    pageX: firstTouch.pageX,
    pageY: firstTouch.pageY
  }
} : function (event) {
  return {
    pageX: event.pageX,
    pageY: event.pageY
  }
};

var Page = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"page"},[_vm._t("before-content"),_c('div',{ref:"content",staticClass:"page-content",style:(_vm.contentStyle)},[(_vm.pull)?_c('div',{staticClass:"pull-to-refresh-layer"},[_c('div',{staticClass:"preloader"}),_c('div',{staticClass:"pull-to-refresh-arrow"})]):_vm._e(),_vm._t("default")],2),_vm._t("after-content")],2)},staticRenderFns: [],
  name: 'f7-page',
  props: {
    pull: {
      type: Function
    },
    ptrCondition: {
      type: Function,
      default: function default$1 () {
        return this.$refs.content.scrollTop === 0
      }
    },
    ptrDistance: {
      default: 72
    }
  },
  data: function data () {
    return {
      pullInitialized: false,
      pullState: defaultPullState()
    }
  },
  methods: {
    _initPull: function _initPull () {
      if (this.pullInitialized) { return }
      this.pullInitialized = true;
      var ref = this.$refs;
      var content = ref.content;
      content.classList.add('pull-to-refresh-content');
      content.addEventListener(TOUCH_START, this._onTouchStart);
      content.addEventListener(TOUCH_MOVE, this._onTouchMove);
      content.addEventListener(TOUCH_END, this._onTouchEnd);
    },
    _destroyPull: function _destroyPull () {
      this.pullInitialized = false;
      this.pullState = defaultPullState();
      var ref = this.$refs;
      var content = ref.content;
      content.classList.remove('pull-to-refresh-content', 'active-state', 'pull-down', 'pull-up', 'refreshing');
      content.removeEventListener(TOUCH_START, this._onTouchStart);
      content.removeEventListener(TOUCH_MOVE, this._onTouchMove);
      content.removeEventListener(TOUCH_END, this._onTouchEnd);
    },
    _onTouchStart: function _onTouchStart (event) {
      var ref = this.$refs;
      var content = ref.content;
      if (!this.ptrCondition()) { return }

      delete this.scrolling;
      var ref$1 = this;
      var pullState = ref$1.pullState;
      var ref$2 = getPageXY(event);
      var pageX = ref$2.pageX;
      var pageY = ref$2.pageY;
      pullState.startX = pageX;
      pullState.startY = pageY;
      pullState.pullStart = true;
      content.classList.add('active-state');
      content.classList.remove('transitioning');
    },
    _onTouchMove: function _onTouchMove (event) {
      var ref = this;
      var pullState = ref.pullState;
      if (!pullState.pullStart) { return }

      var ref$1 = getPageXY(event);
      var pageX = ref$1.pageX;
      var pageY = ref$1.pageY;

      if (typeof this.scrolling !== 'boolean') {
        this.scrolling = Math.abs(pageY - pullState.startY) < Math.abs(pageX - pullState.startX) || pageY < pullState.startY;
      }

      if (this.scrolling) {
        pullState.pullStart = false;
        return
      }

      event.preventDefault();
      var ref$2 = this.$refs;
      var content = ref$2.content;
      content.classList.remove('active-state');

      var distance = pageY - pullState.startY;
      pullState.distance = distance;
      if (pullState.up = distance >= this.ptrDistance) {
        content.classList.remove('pull-down');
        content.classList.add('pull-up');
      } else {
        content.classList.remove('pull-up');
        content.classList.add('pull-down');
      }
    },
    _onTouchEnd: function _onTouchEnd () {
      var this$1 = this;

      var ref = this;
      var pullState = ref.pullState;
      if (!pullState.pullStart) { return }
      pullState.pullStart = false;
      var ref$1 = this.$refs;
      var content = ref$1.content;
      content.classList.remove('active-state');
      pullState.distance = 0;
      if (pullState.up) {
        content.classList.add('transitioning', 'refreshing');
        Promise.resolve(this.pull()).then(function () {
          content.classList.remove('refreshing');

          oneTransitionEnd(content, function () {
            content.classList.remove('pull-up');
          });

          this$1.pullState = defaultPullState();
        });
      } else {
        content.classList.add('transitioning');
        content.classList.remove('pull-down');
        this.pullState = defaultPullState();
      }
    }
  },
  computed: {
    contentStyle: function contentStyle () {
      var ref = this.pullState;
      var distance = ref.distance;
      if (!distance) { return }
      return {
        transform: ("translate3d(0, " + (Math.pow(distance, 0.85)) + "px, 0)")
      }
    }
  },
  watch: {
    pull: function pull (val) {
      if (val) {
        if (!this.pullInitialized) {
          this._initPull();
        }
      } else {
        this._destroyPull();
      }
    }
  },
  mounted: function mounted () {
    if (this.pull) {
      this._initPull();
    }
  },
  beforeDestroy: function beforeDestroy () {
    if (this.pull) {
      this._destroyPull();
    }
  }
};

/**
 * @file navbar 和 toolbar 共用一套显示/隐藏的逻辑，
 * 仅仅只是 CSS 类名不同，
 * 这里抽离出来了公用的逻辑。
 */
/**
 * 显示 navbar/toolbar
 * @param {'navbar'|'toolbar'} type
 * @param {Element} dom
 * @param {boolean} useAnimation
 */
function show (type, dom, useAnimation) {
  var hiddenClass = type + "-hidden";
  var classList = dom.classList;
  if (!classList.contains(hiddenClass)) { return }
  var hidingClass = type + "-hiding";
  classList.remove(hiddenClass, 'not-animated');
  if (useAnimation) {
    classList.add(hidingClass);
    oneTransitionEnd(dom, function () {
      classList.remove(hidingClass);
    });
  }
}

/**
 * 隐藏 navbar/toolbar
 * @param {'navbar'|'toolbar'} type
 * @param {Element} dom
 * @param {boolean} useAnimation
 */
function hide (type, dom, useAnimation) {
  var classList = dom.classList;
  var hiddenClass = type + "-hidden";
  if (classList.contains(hiddenClass)) { return }
  var list = [hiddenClass];
  if (!useAnimation) {
    list.push('not-animated');
  }
  classList.add.apply(classList, list);
}

var cmb = function () {
  return Object.create(null)
};

var store = cmb();

function add (type, name, vm) {
  var types = store[type] || (store[type] = cmb());
  if (types[name]) {
    console.warn(("Already has a " + type + " vm named " + name + "."));
    return
  }
  types[name] = vm;
}

function remove (type, name) {
  var types = store[type];
  if (!types) { return }
  delete types[name];
}

function get (type, name) {
  var types = store[type];
  if (!types) { return }
  return types[name] || null
}

var vmName = {
  props: ['name'],
  created: function created () {
    var vmName = this.name;
    if (vmName) {
      add(this.$options.name, vmName, this);
      this.vmName = vmName;
    }
  },
  beforeDestroy: function beforeDestroy () {
    var vmName = this.vmName;
    if (vmName) {
      remove(this.$options.name, vmName);
    }
  }
};

function noop () {}

var style;

var init = function () {
  init = noop;
  style = document.createElement('style');
  document.head.appendChild(style);
};

var insertStyle = function (text) {
  init();
  style.innerText += text;
};

// https://stackoverflow.com/questions/25827559/rendering-the-dom-outside-the-viewport-in-safari-ios
insertStyle('.navbar.navbar-hidden{-webkit-transform:translate3d(0,-99%,0);transform:translate3d(0,-99%,0)}');

var Navbar = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"navbar"},[_c('div',{staticClass:"navbar-inner"},[_c('div',{ref:"left",staticClass:"left"},[_vm._t("left")],2),_c('div',{ref:"center",staticClass:"center"},[_vm._t("default")],2),_c('div',{ref:"right",staticClass:"right"},[_vm._t("right")],2)])])},staticRenderFns: [],
  name: 'f7-navbar',
  mixins: [vmName],
  methods: {
    show: function show$1 (useAnimation) {
      if ( useAnimation === void 0 ) useAnimation = true;

      show('navbar', this.$el, useAnimation);
    },
    hide: function hide$1 (useAnimation) {
      if ( useAnimation === void 0 ) useAnimation = true;

      hide('navbar', this.$el, useAnimation);
    },
    /**
     * 等同于 `myApp.sizeNavbars(viewContainer)` 方法
     * @see http://framework7.io/docs/navbar.html#related-app-and-view-methods
     */
    size: function size () {
      var ref = this.$refs;
      var left = ref.left;
      var right = ref.right;
      var center = ref.center;
      var diff = left.clientWidth - right.clientWidth;
      center.style.right = diff / 2 + 'px';
    }
  },
  mounted: function mounted () {
    this.$nextTick(this.size);
  }
};

// https://stackoverflow.com/questions/25827559/rendering-the-dom-outside-the-viewport-in-safari-ios
insertStyle('.toolbar.toolbar-hidden{-webkit-transform:translate3d(0,99%,0);transform:translate3d(0,99%,0)}');

var Toolbar = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"toolbar"},[_c('div',{staticClass:"toolbar-inner"},[_vm._t("default")],2)])},staticRenderFns: [],
  name: 'f7-toolbar',
  mixins: [vmName],
  methods: {
    show: function show$1 (useAnimation) {
      if ( useAnimation === void 0 ) useAnimation = true;

      show('toolbar', this.$el, useAnimation);
    },
    hide: function hide$1 (useAnimation) {
      if ( useAnimation === void 0 ) useAnimation = true;

      hide('toolbar', this.$el, useAnimation);
    }
  }
};

var nextFrame = window.requestAnimationFrame || function (cb) {
  setTimeout(cb, 1000 / 60);
};

var DEFAULT_VISIBLE_CLASS = 'modal-overlay-visible';

var VISBLE_CLASS = {
  searchbar: 'searchbar-overlay-active'
};

var Overlay = function Overlay (name, appendTo) {
  if ( appendTo === void 0 ) appendTo = document.body;

  this.name = name;
  this.visibleClass = VISBLE_CLASS[name] || DEFAULT_VISIBLE_CLASS;
  this.parent = appendTo;
  this.node = null;
  this.events = cmb();
};

Overlay.prototype._init = function _init (inHide) {
  this._init = noop;

  var node = document.createElement('div');
  node.classList.add(this.name + '-overlay');
  if (inHide) {
    node.classList.add(this.visibleClass);
  }

  var ref = this;
    var events = ref.events;
  var loop = function ( name ) {
    events[name].forEach(function (handler) {
      node.addEventListener(name, handler);
    });
  };

    for (var name in events) loop( name );

  this.parent.appendChild(node);
  this.node = node;
};

Overlay.prototype.on = function on (name, handler) {
  var ref = this;
    var events = ref.events;
  var eventArr = events[name] || (events[name] = []);
  eventArr.push(handler);
  if (this.node) {
    this.node.addEventListener(name, handler);
  }
};

Overlay.prototype.off = function off (name, handler) {
  var ref = this;
    var events = ref.events;
  var eventArr = events[name];
  if (Array.isArray(eventArr)) {
    var i = eventArr.indexOf(handler);
    if (i >= 0) {
      eventArr.splice(i, 1);
      if (!eventArr.length) {
        delete events[name];
      }
    }
  }

  if (this.node) {
    this.node.removeEventListener(name, handler);
  }
};

Overlay.prototype.show = function show (useAnimation) {
    var this$1 = this;
    if ( useAnimation === void 0 ) useAnimation = true;

  this._init();
  if (this.name === 'preloader-indicator') {
    this.node.style.display = '';
  }
  this.node.classList[useAnimation ? 'remove' : 'add']('not-animated');
  nextFrame(function () {
    this$1.node.classList.add(this$1.visibleClass);
  });
};

Overlay.prototype.hide = function hide (useAnimation) {
    var this$1 = this;
    if ( useAnimation === void 0 ) useAnimation = true;

  if (!useAnimation && !this.node) { return }
  this._init(true);
  this.node.classList[useAnimation ? 'remove' : 'add']('not-animated');
  nextFrame(function () {
    this$1.node.classList.remove(this$1.visibleClass);
    if (this$1.name === 'preloader-indicator') {
      this$1.node.style.display = 'none';
    }
  });
};

Overlay.prototype.destroy = function destroy () {
  delete instances[this.name];
  var ref = this;
    var events = ref.events;
    var node = ref.node;
  if (node) {
    var loop = function ( name ) {
      events[name].forEach(function (handler) {
        node.removeEventListener(name, handler);
      });
    };

      for (var name in events) loop( name );
  }
};

var instances = {};

var co = function (name, appendTo) {
  return instances[name] || (instances[name] = new Overlay(name, appendTo))
};

var m = {
  methods: {
    show: function show (useAnimation) {
      if ( useAnimation === void 0 ) useAnimation = true;

      var ref = this;
      var $el = ref.$el;
      if ($el.style.display === 'block') { return }
      $el.style.display = 'block';
      $el.classList[useAnimation ? 'remove' : 'add']('not-animated');
      nextFrame(function () {
        $el.classList.add('modal-in');
      });
      co(this._modalName).show(useAnimation);
    },
    hide: function hide (useAnimation) {
      if ( useAnimation === void 0 ) useAnimation = true;

      var ref = this;
      var $el = ref.$el;
      if ($el.style.display !== 'block') { return }
      var classList = $el.classList;
      classList.remove('modal-in');
      if (useAnimation) {
        classList.add('modal-out');
        oneTransitionEnd($el, function () {
          $el.style.display = '';
          classList.remove('modal-out');
        });
      } else {
        $el.style.display = '';
      }
      co(this._modalName).hide(useAnimation);
    }
  },
  mounted: function mounted () {
    document.body.appendChild(this.$el);
  },
  beforeDestroy: function beforeDestroy () {
    document.body.removeChild(this.$el);
    co(this._modalName).hide(false);
  }
};

var Popup = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"popup"},[_vm._t("default")],2)},staticRenderFns: [],
  name: 'f7-popup',
  created: function created () {
    this._modalName = 'popup';
  },
  mixins: [m, vmName]
};

insertStyle('.page-from-center-to-right{z-index:300}.page-on-center{z-index:200}.page-on-left,.page-on-right{z-index:100}');

var PageAnimation = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('transition',{attrs:{"css":false},on:{"before-enter":_vm.beforeEnter,"enter":_vm.enter,"after-enter":_vm.afterEnter,"before-leave":_vm.beforeLeave,"leave":_vm.leave,"after-leave":_vm.afterLeave}},[_vm._t("default")],2)},staticRenderFns: [],
  name: 'f7-page-animation',
  props: {
    direction: {
      type: String,
      default: 'none' // 'left' 或 'right'，其他值一律视为无动画处理
    }
  },
  computed: {
    isNone: function isNone () {
      return this.direction !== 'right' && this.direction !== 'left'
    },
    against: function against () {
      switch (this.direction) {
        case 'left':
          return 'right'
        case 'right':
          return 'left'
      }
    }
  },
  methods: {
    beforeEnter: function beforeEnter (el) {
      if (this.isNone) { return }
      el.classList.add(("page-on-" + (this.against)));
    },
    enter: function enter (el, done) {
      var this$1 = this;

      if (this.isNone) {
        done();
        return
      }
      setTimeout(function () {
        oneAnimationEnd(el, done);
        el.classList.remove(("page-on-" + (this$1.against)));
        el.classList.add(("page-from-" + (this$1.against) + "-to-center"));
      }, 0);
    },
    afterEnter: function afterEnter (el) {
      if (this.isNone) { return }
      el.classList.remove(("page-from-" + (this.against) + "-to-center"));
      // el.classList.add('page-on-center')
    },

    beforeLeave: function beforeLeave (el) {
      el.classList.add('page-on-center');
    },
    leave: function leave (el, done) {
      var this$1 = this;

      if (this.isNone) {
        done();
        return
      }
      setTimeout(function () {
        oneAnimationEnd(el, done);
        el.classList.remove('page-on-center');
        el.classList.add(("page-from-center-to-" + (this$1.direction)));
      }, 0);
    },
    afterLeave: function afterLeave (el) {
      if (this.isNone) { return }
      el.classList.remove(("page-from-center-to-" + (this.direction)));
      // el.classList.add(`page-on-${this.direction}`)
    }
  }
};

var SearchBar = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('form',{staticClass:"searchbar searchbar-init",class:{ 'searchbar-active': _vm.active, 'searchbar-not-empty': _vm.value },on:{"submit":function($event){$event.preventDefault();_vm._submit($event);}}},[_c('div',{staticClass:"searchbar-input"},[_c('input',{ref:"input",attrs:{"type":"search","placeholder":_vm.placeholder},domProps:{"value":_vm.value},on:{"input":function($event){_vm._updateValue($event.target.value);},"focus":_vm.enable}}),_vm._v(" "),_c('a',{staticClass:"searchbar-clear",on:{"click":function($event){$event.preventDefault();_vm._clear($event);}}})]),_c('a',{ref:"cancel",staticClass:"searchbar-cancel",staticStyle:{"display":"block"},on:{"click":function($event){$event.preventDefault();_vm.disable($event);}}},[_vm._v(_vm._s(_vm.cancelText))])])},staticRenderFns: [],
  name: 'f7-searchbar',
  mixins: [vmName],
  props: {
    value: {
      type: String,
      default: ''
    },
    placeholder: {
      type: String,
      default: 'Search'
    },
    cancelText: {
      type: String,
      default: 'Cancel'
    },
    overlay: {
      default: true
    }
  },
  data: function data () {
    return {
      active: false
    }
  },
  methods: {
    search: function search (query) {
      this._updateValue(query);
      this._submit();
    },
    enable: function enable () {
      this.active = true;
    },
    disable: function disable () {
      this.clear();
      this.active = false;
    },
    clear: function clear () {
      this._updateValue('');
    },
    _submit: function _submit () {
      this.$emit('search');
    },
    _size: function _size () {
      var this$1 = this;

      this.$nextTick(function () {
        var ref = this$1.$refs;
        var cancel = ref.cancel;
        this$1.cancelWidth = '-' + cancel.clientWidth + 'px';
        if (!this$1.active) {
          cancel.style.marginRight = this$1.cancelWidth;
        }
      });
    },
    _updateValue: function _updateValue (v) {
      this.$emit('input', v);
    },
    _clear: function _clear () {
      this.clear();
      this.$refs.input.focus();
    }
  },
  watch: {
    cancelText: '_size',
    active: function active (active$1) {
      this.$refs.cancel.style.marginRight = active$1 ? '0px' : this.cancelWidth;
    }
  },
  mounted: function mounted () {
    var this$1 = this;

    if (this.overlay) {
      // TODO BUG：seachbar 共用 overlay 导致新的 f7-searchbar 没有 overlay
      var overlay = this.lay = co('searchbar', this.$el.parentElement);
      overlay.on('click', function () {
        this$1.active = false;
      });
      this.$watch(function () { return this$1.active && !this$1.value; }, function (isShow) {
        overlay[isShow ? 'show' : 'hide']();
      });
    }
    this._size();
  },
  beforeDestroy: function beforeDestroy () {
    this.lay && this.lay.destroy();
  }
};

var ProgressBar = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('span',{directives:[{name:"show",rawName:"v-show",value:(_vm.isShow),expression:"isShow"}],class:_vm.classes},[(!_vm.infinite)?_c('span',{style:(_vm.style)}):_vm._e()])},staticRenderFns: [],
  name: 'f7-progressbar',
  mixins: [vmName],
  props: {
    top: {
      type: Boolean,
      default: false
    },
    hidden: {
      type: Boolean,
      default: false
    },
    progress: {
      type: Number,
      default: 0
    },
    infinite: {
      type: Boolean,
      default: false
    },
    multiColor: {
      type: Boolean,
      default: false
    }
  },
  data: function data () {
    return {
      isShow: !this.hidden,
      innerP: this.progress,
      speed: null
    }
  },
  watch: {
    progress: function progress (p) {
      this.set(p);
    }
  },
  computed: {
    classes: function classes () {
      var c = [this.infinite ? 'progressbar-infinite' : 'progressbar'];
      if (this.multiColor) {
        c.push('color-multi');
      }
      return c
    },
    style: function style () {
      var ref = this;
      var innerP = ref.innerP;
      if (innerP < 0) {
        innerP = 0;
      } else if (innerP > 100) {
        innerP = 100;
      }
      var s = "transform: translate3d(" + (innerP - 100) + "%, 0px, 0px)";
      if (this.speed != null) {
        s += ";transition-duration: " + (this.speed) + "ms";
      }
      return s
    }
  },
  methods: {
    /**
     * 设置进度
     * @param {number} progress
     * @param {number} [speed]
     */
    set: function set (progress, speed) {
      this.innerP = progress;
      this.speed = speed;
    },
    show: function show () {
      var this$1 = this;

      if (this.isShow) { return }
      this.isShow = true;
      this.$nextTick(function () {
        this$1.$el.classList.add('progressbar-in');
      });
    },
    hide: function hide () {
      var this$1 = this;

      if (!this.isShow) { return }
      var ref = this;
      var $el = ref.$el;
      var classList = $el.classList;
      classList.remove('progressbar-in');
      classList.add('progressbar-out');
      oneAnimationEnd($el, function () {
        this$1.isShow = false;
        classList.remove('progressbar-out');
      });
    }
  },
  mounted: function mounted () {
    if (this.top) { document.body.appendChild(this.$el); }
  },
  beforeDestroy: function beforeDestroy () {
    if (this.top) { document.body.removeChild(this.$el); }
  }
};

// TODO createOverlay 里也用到了这个常量
var OVERLAY_NAME = 'preloader-indicator';
var Indicator = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{directives:[{name:"show",rawName:"v-show",value:(_vm.isShow),expression:"isShow"}],staticClass:"preloader-indicator-modal"},[_c('span',{staticClass:"preloader preloader-white"})])},staticRenderFns: [],
  data: function data () {
    return {
      isShow: false
    }
  },
  methods: {
    show: function show () {
      co(OVERLAY_NAME).show(false);
      this.isShow = true;
    },
    hide: function hide () {
      co(OVERLAY_NAME).hide(false);
      this.isShow = false;
    }
  }
};

var idt;

var init$1 = function () {
  init$1 = noop;
  idt = new (Vue.extend(Indicator))();
  idt.$mount();
  document.body.appendChild(idt.$el);
};

function showIndicator () {
  init$1();
  idt.show();
}

function hideIndicator () {
  if (!idt) { return }
  init$1();
  idt.hide();
}

function showNavbar (name, useAnimate) {
  var vm = get('f7-navbar', name);
  if (vm) { vm.show(useAnimate); }
}

function hideNavbar (name, useAnimate) {
  var vm = get('f7-navbar', name);
  if (vm) { vm.hide(useAnimate); }
}

function sizeNavbar (name) {
  var vm = get('f7-navbar', name);
  if (vm) { vm.size(); }
}

function popup (name, useAnimate) {
  var vm = get('f7-popup', name);
  if (vm) { vm.show(useAnimate); }
}

function closePopup (name, useAnimate) {
  var vm = get('f7-popup', name);
  if (vm) { vm.hide(useAnimate); }
}

var searchbar = function (name) {
  return get('f7-searchbar', name)
};

function showToolbar (name, useAnimate) {
  var vm = get('f7-toolbar', name);
  if (vm) { vm.show(useAnimate); }
}

function hideToolbar (name, useAnimate) {
  var vm = get('f7-toolbar', name);
  if (vm) { vm.hide(useAnimate); }
}

var ModalTransition = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('transition',{attrs:{"css":false},on:{"before-enter":_vm.beforeEnter,"enter":_vm.enter,"before-leave":_vm.beforeLeave,"leave":_vm.leave,"after-leave":_vm.afterLeave}},[_vm._t("default")],2)},staticRenderFns: [],
  methods: {
    beforeEnter: function beforeEnter (el) {
      el.style.display = 'block';
    },
    enter: function enter (el, done) {
      nextFrame(function () { el.classList.add('modal-in'); });
      oneTransitionEnd(el, done);
    },
    beforeLeave: function beforeLeave (el) {
      el.classList.remove('modal-in');
    },
    leave: function leave (el, done) {
      el.classList.add('modal-out');
      oneTransitionEnd(el, done);
    },
    afterLeave: function afterLeave (el) {
      el.classList.remove('modal-out');
    }
  }
};

var PROMPT = 'prompt';
var PRELOADER = 'preloader';
var CONFIRM = 'confirm';
var LOGIN = 'login';
var PASSWORD = 'password';
var ALERT = 'alert';
var CUSTOM = 'custom';

var Modal = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('modal-transition',[(_vm.isShow)?_c('div',{ref:"modalEl",staticClass:"modal",class:{ 'modal-no-buttons': _vm.isPreloader, 'modal-preloader': _vm.isPreloader },style:({ 'margin-top': _vm.marginTop })},[_c('div',{staticClass:"modal-inner"},[_c('div',{staticClass:"modal-title",domProps:{"textContent":_vm._s(_vm.title)}}),(_vm.isPreloader)?_c('div',{staticClass:"modal-text"},[_c('div',{staticClass:"preloader"})]):_c('div',{staticClass:"modal-text",domProps:{"textContent":_vm._s(_vm.text)}}),(_vm.isPrompt)?_c('div',{staticClass:"input-field"},[_c('input',{directives:[{name:"model",rawName:"v-model",value:(_vm.promptValue),expression:"promptValue"}],staticClass:"modal-text-input",attrs:{"type":"text"},domProps:{"value":(_vm.promptValue)},on:{"input":function($event){if($event.target.composing){ return; }_vm.promptValue=$event.target.value;}}})]):_vm._e(),(_vm.isPassword)?_c('div',{staticClass:"input-field"},[_c('input',{directives:[{name:"model",rawName:"v-model",value:(_vm.password),expression:"password"}],staticClass:"modal-text-input",attrs:{"type":"password","placeholder":"Password"},domProps:{"value":(_vm.password)},on:{"input":function($event){if($event.target.composing){ return; }_vm.password=$event.target.value;}}})]):_vm._e(),(_vm.isLogin)?[_c('div',{staticClass:"input-field modal-input-double"},[_c('input',{directives:[{name:"model",rawName:"v-model",value:(_vm.username),expression:"username"}],staticClass:"modal-text-input",attrs:{"type":"text","placeholder":"Username"},domProps:{"value":(_vm.username)},on:{"input":function($event){if($event.target.composing){ return; }_vm.username=$event.target.value;}}})]),_c('div',{staticClass:"input-field modal-input-double"},[_c('input',{directives:[{name:"model",rawName:"v-model",value:(_vm.password),expression:"password"}],staticClass:"modal-text-input",attrs:{"type":"password","name":"modal-password","placeholder":"Password"},domProps:{"value":(_vm.password)},on:{"input":function($event){if($event.target.composing){ return; }_vm.password=$event.target.value;}}})])]:_vm._e()],2),(_vm.isCustom)?_c('div',{staticClass:"modal-buttons",class:['modal-buttons-' + _vm.buttons.length, { 'modal-buttons-vertical': _vm.vertical }]},_vm._l((_vm.buttons),function(btn,index){return _c('span',{key:index,staticClass:"modal-button",class:{ 'modal-button-bold': btn.bold },domProps:{"textContent":_vm._s(btn.text)},on:{"click":function($event){_vm.$emit(_vm.type, index, btn);}}})})):_c('div',{staticClass:"modal-buttons",class:{ 'modal-buttons-1': _vm.isAlert, 'modal-buttons-2': _vm.isConfirm || _vm.isPrompt }},[(_vm.hasCancelButton)?_c('span',{staticClass:"modal-button",on:{"click":function($event){_vm.$emit(_vm.type, false);}}},[_vm._v(_vm._s(_vm.cancelText)+" ")]):_vm._e(),_c('span',{staticClass:"modal-button modal-button-bold",on:{"click":function($event){_vm.$emit(_vm.type, true);}}},[_vm._v(_vm._s(_vm.okText))])])]):_vm._e()])},staticRenderFns: [],
  components: {
    ModalTransition: ModalTransition
  },
  data: function data () {
    return {
      isShow: false,
      type: null,
      promptValue: '',
      username: '',
      password: '',
      title: '',
      text: '',
      buttons: [],
      vertical: false,
      marginTop: '',
      okText: 'OK',
      cancelText: 'Cancel'
    }
  },
  computed: {
    isPreloader: function isPreloader () {
      return this.type === PRELOADER
    },
    isPrompt: function isPrompt () {
      return this.type === PROMPT
    },
    isPassword: function isPassword () {
      return this.type === PASSWORD
    },
    isLogin: function isLogin () {
      return this.type === LOGIN
    },
    isAlert: function isAlert () {
      return this.type === ALERT
    },
    isConfirm: function isConfirm () {
      return this.type === CONFIRM
    },
    isCustom: function isCustom () {
      return this.type === CUSTOM
    },
    hasCancelButton: function hasCancelButton () {
      return this.isConfirm || this.isPrompt || this.isLogin || this.isPassword
    }
  }
};

var modalVm;

var init$2 = function () {
  init$2 = noop;
  modalVm = new (Vue.extend(Modal))();
  modalVm.$mount();
  document.body.appendChild(modalVm.$el);
};

function showModal () {
  co('modal').show(true);
  modalVm.isShow = true;
  modalVm.$nextTick(function () {
    var ref = modalVm.$refs;
    var modalEl = ref.modalEl;
    if (!modalEl) { return }
    modalVm.marginTop = '-' + (modalEl.clientHeight / 2) + 'px';
  });
}

function hideModal () {
  co('modal').hide(true);
  modalVm.isShow = false;
}

/**
 * 弹出一个警告框
 * @param {string} text
 * @param {string} [title]
 * @param {string} [okText]
 * @return {Promise}
 */
function alert (text, title, okText) {
  if ( title === void 0 ) title = 'Notice';
  if ( okText === void 0 ) okText = 'OK';

  init$2();
  modalVm.type = ALERT;
  modalVm.text = text;
  modalVm.title = title;
  modalVm.okText = okText;
  showModal();
  return new Promise(function (resolve) {
    modalVm.$once(ALERT, function () {
      hideModal();
      modalVm.$nextTick(resolve);
    });
  })
}

/**
 * 弹出一个确认框
 * @param {string} text
 * @param {string} [title]
 * @param {string} [okText]
 * @param {string} [cancelText]
 * @return {Promise}
 */
function confirm (text, title, okText, cancelText) {
  if ( title === void 0 ) title = 'Confirm';
  if ( okText === void 0 ) okText = 'OK';
  if ( cancelText === void 0 ) cancelText = 'Cancel';

  init$2();
  modalVm.type = CONFIRM;
  modalVm.text = text;
  modalVm.title = title;
  modalVm.okText = okText;
  modalVm.cancelText = cancelText;
  showModal();
  return new Promise(function (resolve, reject) {
    modalVm.$once(CONFIRM, function (ok) {
      hideModal();
      modalVm.$nextTick(function () {
        if (ok) {
          resolve();
        } else {
          reject();
        }
      });
    });
  })
}

/**
 * 弹出一个 Prompt 框
 * @param {String} text
 * @param {String} [title]
 * @param {string} [okText]
 * @param {string} [cancelText]
 * @return {Promise}
 */
function prompt (text, title, okText, cancelText) {
  if ( title === void 0 ) title = 'Prompt';
  if ( okText === void 0 ) okText = 'OK';
  if ( cancelText === void 0 ) cancelText = 'Cancel';

  init$2();
  modalVm.type = PROMPT;
  modalVm.text = text;
  modalVm.title = title;
  modalVm.promptValue = '';
  modalVm.okText = okText;
  modalVm.cancelText = cancelText;
  showModal();
  return new Promise(function (resolve, reject) {
    modalVm.$once(PROMPT, function (ok) {
      hideModal();
      modalVm.$nextTick(function () {
        var v = modalVm.promptValue;
        if (ok) {
          resolve(v);
        } else {
          reject(v);
        }
      });
    });
  })
}

/**
 * 显示登录框
 * @param {string} text
 * @param {string} [title]
 * @param {string} [okText]
 * @param {string} [cancelText]
 * @returns {Promise}
 */
function modalLogin (text, title, okText, cancelText) {
  if ( title === void 0 ) title = 'Login';
  if ( okText === void 0 ) okText = 'OK';
  if ( cancelText === void 0 ) cancelText = 'Cancel';

  init$2();
  modalVm.type = LOGIN;
  modalVm.text = text;
  modalVm.title = title;
  modalVm.okText = okText;
  modalVm.cancelText = cancelText;
  modalVm.username = modalVm.password = '';
  showModal();
  return new Promise(function (resolve, reject) {
    modalVm.$once(LOGIN, function (ok) {
      hideModal();
      modalVm.$nextTick(function () {
        var v = {
          username: modalVm.username,
          password: modalVm.password
        };
        if (ok) {
          resolve(v);
        } else {
          reject(v);
        }
      });
    });
  })
}

/**
 * 显示密码框
 * @param {string} text
 * @param {string} title
 * @param {string} [okText]
 * @param {string} [cancelText]
 * @return {Promise}
 */
function modalPassword (text, title, okText, cancelText) {
  if ( title === void 0 ) title = 'Password';
  if ( okText === void 0 ) okText = 'OK';
  if ( cancelText === void 0 ) cancelText = 'Cancel';

  init$2();
  modalVm.type = PASSWORD;
  modalVm.text = text;
  modalVm.title = title;
  modalVm.okText = okText;
  modalVm.cancelText = cancelText;
  modalVm.password = '';
  showModal();
  return new Promise(function (resolve, reject) {
    modalVm.$once(PASSWORD, function (ok) {
      hideModal();
      modalVm.$nextTick(function () {
        var v = modalVm.password;
        if (ok) {
          resolve(v);
        } else {
          reject(v);
        }
      });
    });
  })
}

/**
 * 弹出一个加载中遮罩层
 * @param {string} [title]
 */
function showPreloader (title) {
  if ( title === void 0 ) title = 'Loading';

  init$2();
  modalVm.type = PRELOADER;
  modalVm.title = title;
  showModal();
}

function hidePreloader () {
  if (modalVm) {
    hideModal();
  }
}

/**
 * 显示自定义的 modal
 * @param parameters
 * @param {string} parameters.text
 * @param {string} parameters.title
 * @param {{ text: string, bold: boolean, close: boolean }[]} parameters.buttons
 * @param {boolean} parameters.verticalButtons
 */
function modal (parameters) {
  init$2();
  modalVm.type = CUSTOM;
  modalVm.text = parameters.text || '';
  modalVm.title = parameters.title || '';
  modalVm.buttons = parameters.buttons || [];
  modalVm.vertical = parameters.verticalButtons;
  showModal();
  return new Promise(function (resolve) {
    modalVm.$once(CUSTOM, function (index, btn) {
      if (btn.close !== false) {
        hideModal();
      }
      modalVm.$nextTick(function () { return resolve(index); });
    });
  })
}

var ActionSheet = {render: function(){var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"actions-modal",staticStyle:{"position":"fixed"}},_vm._l((_vm.groups),function(buttons){return _c('div',{staticClass:"actions-modal-group"},_vm._l((buttons),function(btn){return _c('div',{class:_vm.getBtnClass(btn),style:(_vm.getBtnStyle(btn)),on:{"click":function($event){_vm.choose(btn);}}},[_vm._v(_vm._s(btn.text))])}))}))},staticRenderFns: [],
  data: function data () {
    this._modalName = 'modal';
    return {
      groups: []
    }
  },
  mixins: [m],
  methods: {
    choose: function choose (btn) {
      if (btn.label || btn.disabled) { return }
      this.hide();
      if (typeof btn.onClick === 'function') { btn.onClick(); }
      this.$emit('choose', btn);
    },
    cancel: function cancel () {
      this.hide();
      this.$emit('choose', null);
    },
    getBtnClass: function getBtnClass (btn) {
      var classes = [];
      classes.push(btn.label ? 'actions-modal-label' : 'actions-modal-button');
      if (btn.bold) {
        classes.push('actions-modal-button-bold');
      }
      if (btn.disabled) {
        classes.push('disabled');
      }
      return classes
    },
    getBtnStyle: function getBtnStyle (btn) {
      var color = btn.color;
      var bg = btn.bg;
      var style = {};
      if (color) {
        style.color = color;
      }
      if (bg) {
        style.backgroundColor = bg;
      }
      return style
    }
  },
  created: function created () {
    co(this._modalName).on('click', this.cancel);
  }
};

var actionSheet;

var init$3 = function () {
  init$3 = noop;
  actionSheet = new (Vue.extend(ActionSheet))();
  actionSheet.$mount();
  document.body.appendChild(actionSheet.$el);
};

function actions (buttons) {
  if (!Array.isArray(buttons) || !buttons.length) { return }
  init$3();
  actionSheet.groups = Array.isArray(buttons[0]) ? buttons : [buttons];
  Vue.nextTick(actionSheet.show);
  return new Promise(function (resolve, reject) {
    actionSheet.$once('choose', function (btn) {
      if (btn == null) {
        return reject()
      }
      resolve(btn);
    });
  })
}

var singleProgress;

/**
 * 设置指定进度条的进度
 * @param {string} name - 进度条的名称
 * @param {number} progress - 进度
 * @param {number} [speed] - 调整到此进度所需的时间
 */
function setProgressbar (name, progress, speed) {
  var vm = get('f7-progressbar', name);
  if (!vm) { return }
  vm.set(progress, speed);
}

/**
 * 隐藏进度条
 * @param {string} [name] - 如果提供，则隐藏指定的进度条；如果没有提供，则隐藏全局的无限进度条
 */
function hideProgressbar (name) {
  if (name) {
    var vm = get('f7-progressbar', name);
    if (vm) { vm.hide(); }
    return
  }

  if (singleProgress) {
    singleProgress.hide();
  }
}

/**
 * 显示进度条
 * @param {string|number} [nameOrProgress] - 如果这个参数是字符串，则显示指定的进度条；
 *                                           如果这个参数是数字，则创建一个全局进度条并显示；
 *                                           如果这个参数是 true，则创建一个彩色的无限进度条并显示；
 *                                           不传或者传其它值则会创建一个普通全局的无限进度条并显示。
 */
function showProgressbar (nameOrProgress) {
  if (typeof nameOrProgress === 'string') {
    var vm = get('f7-progressbar', nameOrProgress);
    if (vm) { vm.show(); }
    return
  }

  if (!singleProgress) {
    singleProgress = new (Vue.extend(ProgressBar))({
      propsData: {
        hidden: true,
        top: true
      }
    }).$mount();
  }

  if (typeof nameOrProgress === 'number') {
    singleProgress.infinite = false;
    singleProgress.set(nameOrProgress);
  } else {
    singleProgress.infinite = true;
    singleProgress.multiColor = nameOrProgress === true;
  }

  singleProgress.show();
}

function install (Vue$$1) {
  [
    Page,
    Navbar,
    Toolbar,
    Popup,
    PageAnimation,
    SearchBar,
    ProgressBar
  ].forEach(function (cpt) {
    Vue$$1.component(cpt.name, cpt);
  });
}

exports.Page = Page;
exports.Navbar = Navbar;
exports.Toolbar = Toolbar;
exports.Popup = Popup;
exports.PageAnimation = PageAnimation;
exports.SearchBar = SearchBar;
exports.ProgressBar = ProgressBar;
exports.install = install;
exports.searchbar = searchbar;
exports.showIndicator = showIndicator;
exports.hideIndicator = hideIndicator;
exports.showNavbar = showNavbar;
exports.hideNavbar = hideNavbar;
exports.sizeNavbar = sizeNavbar;
exports.popup = popup;
exports.closePopup = closePopup;
exports.showToolbar = showToolbar;
exports.hideToolbar = hideToolbar;
exports.alert = alert;
exports.confirm = confirm;
exports.prompt = prompt;
exports.modalLogin = modalLogin;
exports.modalPassword = modalPassword;
exports.showPreloader = showPreloader;
exports.hidePreloader = hidePreloader;
exports.modal = modal;
exports.actions = actions;
exports.setProgressbar = setProgressbar;
exports.hideProgressbar = hideProgressbar;
exports.showProgressbar = showProgressbar;

Object.defineProperty(exports, '__esModule', { value: true });

})));
